Class: Clerk::Models::Operations::UpdateRoleSetType
- Inherits:
-
Object
- Object
- Clerk::Models::Operations::UpdateRoleSetType
- Includes:
- Crystalline::Enum
- Defined in:
- lib/clerk/models/operations/updateroleset_type.rb
Overview
UpdateRoleSetType - Set to “initial” to make this the default role set for new organizations. Only one role set can be “initial” per instance; setting this will change any existing initial role set to “custom”.
Method Summary
Methods included from Crystalline::Enum
#==, #eql?, #hash, included, #initialize, #known?, #serialize