Class: Clerk::Models::Components::OrganizationDomainVerification Deprecated
- Inherits:
-
Object
- Object
- Clerk::Models::Components::OrganizationDomainVerification
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/clerk/models/components/organizationdomain_verification.rb
Overview
Deprecated.
class: This will be removed in a future release, please migrate away from it as soon as possible.
Deprecated alias for ‘affiliation_verification`. Kept for backward compatibility on the current API version; will be removed in the next API version. Prefer `affiliation_verification`.
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize(status:, strategy:, attempts: nil, expire_at: nil, verified_at: nil) ⇒ OrganizationDomainVerification
constructor
A new instance of OrganizationDomainVerification.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize(status:, strategy:, attempts: nil, expire_at: nil, verified_at: nil) ⇒ OrganizationDomainVerification
Returns a new instance of OrganizationDomainVerification.
31 32 33 34 35 36 37 |
# File 'lib/clerk/models/components/organizationdomain_verification.rb', line 31 def initialize(status:, strategy:, attempts: nil, expire_at: nil, verified_at: nil) @status = status @strategy = strategy @attempts = attempts @expire_at = expire_at @verified_at = verified_at end |
Instance Method Details
#==(other) ⇒ Object
40 41 42 43 44 45 46 47 48 |
# File 'lib/clerk/models/components/organizationdomain_verification.rb', line 40 def ==(other) return false unless other.is_a? self.class return false unless @status == other.status return false unless @strategy == other.strategy return false unless @attempts == other.attempts return false unless @expire_at == other.expire_at return false unless @verified_at == other.verified_at true end |