Class: Clerk::SDK
- Inherits:
-
Object
- Object
- Clerk::SDK
- Defined in:
- lib/clerk/sdk.rb
Constant Summary collapse
- DEFAULT_HEADERS =
{ "User-Agent" => "Clerk/#{Clerk::VERSION}; Faraday/#{Faraday::VERSION}; Ruby/#{RUBY_VERSION}", "X-Clerk-SDK" => "ruby/#{Clerk::VERSION}" }
- JWKS_CACHE_LIFETIME =
How often (in seconds) should JWKs be refreshed
3600
Instance Method Summary collapse
- #allowlist ⇒ Object
- #allowlist_identifiers ⇒ Object
- #clients ⇒ Object
-
#decode_token(token) ⇒ Object
Returns the decoded JWT payload without verifying if the signature is valid.
- #email_addresses ⇒ Object
- #emails ⇒ Object
-
#initialize(api_key: nil, base_url: nil, logger: nil, ssl_verify: true, connection: nil) ⇒ SDK
constructor
1 hour.
- #interstitial(refresh = false) ⇒ Object
- #jwks ⇒ Object
- #organizations ⇒ Object
- #phone_numbers ⇒ Object
- #request(method, path, query: [], body: nil, timeout: nil) ⇒ Object
- #sessions ⇒ Object
- #sms_messages ⇒ Object
- #users ⇒ Object
-
#verify_token(token, force_refresh_jwks: false, algorithms: ['RS256'], timeout: 5) ⇒ Object
Decode the JWT and verify it's valid (verify claims, signature etc.) using the provided algorithms.
Constructor Details
#initialize(api_key: nil, base_url: nil, logger: nil, ssl_verify: true, connection: nil) ⇒ SDK
1 hour
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/clerk/sdk.rb', line 33 def initialize(api_key: nil, base_url: nil, logger: nil, ssl_verify: true, connection: nil) @jwks_fetched_at = nil if connection # Inject a Faraday::Connection for testing or full control over Faraday @conn = connection return else base_url = base_url || Clerk.configuration.base_url base_uri = if !base_url.end_with?("/") URI("#{base_url}/") else URI(base_url) end api_key = api_key || Clerk.configuration.api_key logger = logger || Clerk.configuration.logger @conn = Faraday.new( url: base_uri, headers: DEFAULT_HEADERS, ssl: {verify: ssl_verify} ) do |f| f.request :url_encoded f.request :authorization, "Bearer", api_key if logger f.response :logger, logger do |l| l.filter(/(Authorization: "Bearer) (\w+)/, '\1 [SECRET]') end end end end end |
Instance Method Details
#allowlist ⇒ Object
108 109 110 |
# File 'lib/clerk/sdk.rb', line 108 def allowlist Resources::Allowlist.new(self) end |
#allowlist_identifiers ⇒ Object
104 105 106 |
# File 'lib/clerk/sdk.rb', line 104 def allowlist_identifiers Resources::AllowlistIdentifiers.new(self) end |
#clients ⇒ Object
112 113 114 |
# File 'lib/clerk/sdk.rb', line 112 def clients Resources::Clients.new(self) end |
#decode_token(token) ⇒ Object
Returns the decoded JWT payload without verifying if the signature is valid.
WARNING: This will not verify whether the signature is valid. You should not use this for untrusted messages! You most likely want to use verify_token.
158 159 160 |
# File 'lib/clerk/sdk.rb', line 158 def decode_token(token) JWT.decode(token, nil, false).first end |
#email_addresses ⇒ Object
116 117 118 |
# File 'lib/clerk/sdk.rb', line 116 def email_addresses Resources::EmailAddresses.new(self) end |
#emails ⇒ Object
120 121 122 |
# File 'lib/clerk/sdk.rb', line 120 def emails Resources::Emails.new(self) end |
#interstitial(refresh = false) ⇒ Object
148 149 150 |
# File 'lib/clerk/sdk.rb', line 148 def interstitial(refresh=false) request(:get, "internal/interstitial") end |
#jwks ⇒ Object
144 145 146 |
# File 'lib/clerk/sdk.rb', line 144 def jwks Resources::JWKS.new(self) end |
#organizations ⇒ Object
124 125 126 |
# File 'lib/clerk/sdk.rb', line 124 def organizations Resources::Organizations.new(self) end |
#phone_numbers ⇒ Object
128 129 130 |
# File 'lib/clerk/sdk.rb', line 128 def phone_numbers Resources::PhoneNumbers.new(self) end |
#request(method, path, query: [], body: nil, timeout: nil) ⇒ Object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/clerk/sdk.rb', line 63 def request(method, path, query: [], body: nil, timeout: nil) response = case method when :get @conn.get(path, query) do |req| req..timeout = timeout if timeout end when :post @conn.post(path, body) do |req| req.body = body req..timeout = timeout if timeout end when :patch @conn.patch(path, body) do |req| req.body = body req..timeout = timeout if timeout end when :delete @conn.delete(path) do |req| req..timeout = timeout if timeout end end body = if response["Content-Type"] == "application/json" JSON.parse(response.body) else response.body end if response.success? body else klass = case body.dig("errors", 0, "code") when "cookie_invalid", "client_not_found", "resource_not_found" Errors::Authentication else Errors::Fatal end raise klass.new(body, status: response.status) end end |
#sessions ⇒ Object
132 133 134 |
# File 'lib/clerk/sdk.rb', line 132 def sessions Resources::Sessions.new(self) end |
#sms_messages ⇒ Object
136 137 138 |
# File 'lib/clerk/sdk.rb', line 136 def Resources::SMSMessages.new(self) end |
#users ⇒ Object
140 141 142 |
# File 'lib/clerk/sdk.rb', line 140 def users Resources::Users.new(self) end |
#verify_token(token, force_refresh_jwks: false, algorithms: ['RS256'], timeout: 5) ⇒ Object
Decode the JWT and verify it's valid (verify claims, signature etc.) using the provided algorithms.
JWKS are cached for JWKS_CACHE_LIFETIME seconds, in order to avoid unecessary roundtrips. In order to invalidate the cache, pass `force_refresh_jwks: true`.
A timeout for the request to the JWKs endpoint can be set with the `timeout` argument.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/clerk/sdk.rb', line 171 def verify_token(token, force_refresh_jwks: false, algorithms: ['RS256'], timeout: 5) jwk_loader = ->() do @cached_jwks = nil if [:invalidate] || force_refresh_jwks @cached_jwks = nil if @jwks_fetched_at && Time.now.to_i - @jwks_fetched_at > JWKS_CACHE_LIFETIME @cached_jwks ||= begin keys = jwks.all["keys"] @jwks_fetched_at = Time.now.to_i # JWT.decode requires that the 'keys' key in the Hash is a symbol (as # opposed to a string which our SDK returns by default) { keys: keys } end end JWT.decode(token, nil, true, algorithms: algorithms, jwks: jwk_loader).first end |